from enum import Enum, auto


class UniversalDependencyPosType(Enum):
    
    ADJ = auto()
    ADV = auto()
    INTJ = auto()
    NOUN = auto()
    PROPN = auto()
    VERB = auto()
    ADP = auto()
    AUX = auto()
    CCONJ = auto()
    DET = auto()
    NUM = auto()
    PART = auto()
    PRON = auto()
    SCONJ = auto()
    PUNCT = auto()
    SYM = auto()
    X = auto()
