from enum import Enum, auto


class UniversalDependencyType(Enum):

    ACL = auto()
    ADVCL = auto()
    ADVMOD = auto()
    AMOD = auto()
    APPOS = auto()
    AUX = auto()
    AUXPASS = auto()
    CASE = auto()
    CC = auto()
    CCOMP = auto()
    CLF = auto()
    COMPOUND = auto()
    CONJ = auto()
    COP = auto()
    CSUBJ = auto()
    DEP = auto()
    DET = auto()
    DISCOURSE = auto()
    DISLOCATED = auto()
    EXPL = auto()
    FIXED = auto()
    FLAT = auto()
    FOREIGN = auto()
    GOESWITH = auto()
    IOBJ = auto()
    LIST = auto()
    MARK = auto()
    NMOD = auto()
    NSUBJ = auto()
    NUMMOD = auto()
    OBJ = auto()
    OBL = auto()
    ORPHAN = auto()
    PARATAXIS = auto()
    PUNCT = auto()
    REPARANDUM = auto()
    ROOT = auto()
    VOCATIVE = auto()
    XCOMP = auto()
    ACL_RELCL = auto()
    AUX_PASS = auto()
    CC_PRECONJ = auto()
    COMPOUND_PRT = auto()
    DET_PREDET = auto()
    FLAT_FOREIGN = auto()
    NSUBJ_PASS = auto()
    CSUBJ_PASS = auto()
    NMOD_NPMOD = auto()
    NMOD_POSS = auto()
    NMOD_TMOD = auto()
    ADVMOD_EMPH = auto()
    AUX_Q = auto()
    COMPOUND_LVC = auto()
    COMPOUND_REDUP = auto()
    CSUBJ_COP = auto()
    NMOD_COMP = auto()
    NMOD_PART = auto()
    NSUBJ_COP = auto()
    OBL_AGENT = auto()
    OBL_TMOD = auto()
