from enum import Enum, auto


class StanfordDependencyType(Enum):
    ACOMP = auto()
    ADVCL = auto()
    ADVMOD = auto()
    AGENT = auto()
    AMOD = auto()
    APPOS = auto()
    AUX = auto()
    AUXPASS = auto()
    CC = auto()
    CCOMP = auto()
    CONJ = auto()
    COP = auto()
    CSUBJ = auto()
    CSUBJPASS = auto()
    DEP = auto()
    DET = auto()
    DISCOURSE = auto()
    DOBJ = auto()
    EXPL = auto()
    GOESWITH = auto()
    IOBJ = auto()
    MARK = auto()
    MWE = auto()
    NEG = auto()
    NN = auto()
    NPADVMOD = auto()
    NSUBJ = auto()
    NSUBJPASS = auto()
    NUM = auto()
    NUMBER = auto()
    PARATAXIS = auto()
    PCOMP = auto()
    POBJ = auto()
    POSS = auto()
    POSSESSIVE = auto()
    PRECONJ = auto()
    PREDET = auto()
    PREP = auto()
    PREPC = auto()
    PRT = auto()
    PUNCT = auto()
    QUANTMOD = auto()
    RCMOD = auto()
    REF = auto()
    ROOT = auto()
    TMOD = auto()
    VMOD = auto()
    XCOMP = auto()
    XSUBJ = auto()
